@@ -1,9 +1,9 @@
 package Dancer2::Core::Factory;
 # ABSTRACT: Instantiate components by type and name
-$Dancer2::Core::Factory::VERSION = '0.166001';
+$Dancer2::Core::Factory::VERSION = '1.1.1';
 use Moo;
 use Dancer2::Core;
-use Class::Load 'try_load_class';
+use Module::Runtime 'use_module';
 use Carp 'croak';
 
 sub create {
@@ -13,8 +13,8 @@ sub create {
     $name = Dancer2::Core::camelize($name);
     my $component_class = "Dancer2::${type}::${name}";
 
-    my ( $ok, $error ) = try_load_class($component_class);
-    $ok or croak "Unable to load class for $type component $name: $error";
+    eval { use_module($component_class); 1; }
+        or croak "Unable to load class for $type component $name: $@";
 
     return $component_class->new(%options);
 }
@@ -33,7 +33,7 @@ Dancer2::Core::Factory - Instantiate components by type and name
 
 =head1 VERSION
 
-version 0.166001
+version 1.1.1
 
 =head1 AUTHOR
 
@@ -41,7 +41,7 @@ Dancer Core Developers
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Alexis Sukrieh.
+This software is copyright (c) 2024 by Alexis Sukrieh.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
